( cd usr/bin ; rm -rf dvilj )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/dvilj dvilj )
( cd usr/bin ; rm -rf dvilj2p )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/dvilj2p dvilj2p )
( cd usr/bin ; rm -rf dvilj4 )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/dvilj4 dvilj4 )
( cd usr/bin ; rm -rf dvilj4l )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/dvilj4l dvilj4l )
( cd usr/lib/texmf/tex/dvilj ; rm -rf 2up.sty )
( cd usr/lib/texmf/tex/dvilj ; ln -sf /cdrom/live/usr/lib/texmf/tex/dvilj/2up.sty 2up.sty )
( cd usr/lib/texmf/tex/dvilj ; rm -rf cgalbertus.sty )
( cd usr/lib/texmf/tex/dvilj ; ln -sf /cdrom/live/usr/lib/texmf/tex/dvilj/cgalbertus.sty cgalbertus.sty )
( cd usr/lib/texmf/tex/dvilj ; rm -rf cgantiqueolive.sty )
( cd usr/lib/texmf/tex/dvilj ; ln -sf /cdrom/live/usr/lib/texmf/tex/dvilj/cgantiqueolive.sty cgantiqueolive.sty )
( cd usr/lib/texmf/tex/dvilj ; rm -rf cgcourier.sty )
( cd usr/lib/texmf/tex/dvilj ; ln -sf /cdrom/live/usr/lib/texmf/tex/dvilj/cgcourier.sty cgcourier.sty )
( cd usr/lib/texmf/tex/dvilj ; rm -rf cggothic.sty )
( cd usr/lib/texmf/tex/dvilj ; ln -sf /cdrom/live/usr/lib/texmf/tex/dvilj/cggothic.sty cggothic.sty )
( cd usr/lib/texmf/tex/dvilj ; rm -rf cgtimes.sty )
( cd usr/lib/texmf/tex/dvilj ; ln -sf /cdrom/live/usr/lib/texmf/tex/dvilj/cgtimes.sty cgtimes.sty )
( cd usr/lib/texmf/tex/dvilj ; rm -rf cgunivers.sty )
( cd usr/lib/texmf/tex/dvilj ; ln -sf /cdrom/live/usr/lib/texmf/tex/dvilj/cgunivers.sty cgunivers.sty )
( cd usr/lib/texmf/tex/dvilj ; rm -rf graybox.sty )
( cd usr/lib/texmf/tex/dvilj ; ln -sf /cdrom/live/usr/lib/texmf/tex/dvilj/graybox.sty graybox.sty )
( cd usr/lib/texmf/tex/dvilj ; rm -rf hpfonts.sty )
( cd usr/lib/texmf/tex/dvilj ; ln -sf /cdrom/live/usr/lib/texmf/tex/dvilj/hpfonts.sty hpfonts.sty )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf mhvb.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/mhvb.tfm mhvb.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf mhvbi.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/mhvbi.tfm mhvbi.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf mhvbiq.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/mhvbiq.tfm mhvbiq.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf mhvbq.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/mhvbq.tfm mhvbq.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf mhvr.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/mhvr.tfm mhvr.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf mhvri.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/mhvri.tfm mhvri.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf mhvriq.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/mhvriq.tfm mhvriq.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf mhvrq.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/mhvrq.tfm mhvrq.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf arb10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/arb10u.tfm arb10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf arb2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/arb2n.tfm arb2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf arb7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/arb7j.tfm arb7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf arb8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/arb8u.tfm arb8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf arb9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/arb9t.tfm arb9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf ari10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/ari10u.tfm ari10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf ari2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/ari2n.tfm ari2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf ari7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/ari7j.tfm ari7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf ari8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/ari8u.tfm ari8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf ari9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/ari9t.tfm ari9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf arj10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/arj10u.tfm arj10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf arj2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/arj2n.tfm arj2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf arj7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/arj7j.tfm arj7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf arj8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/arj8u.tfm arj8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf arj9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/arj9t.tfm arj9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf arr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/arr10u.tfm arr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf arr2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/arr2n.tfm arr2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf arr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/arr7j.tfm arr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf arr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/arr8u.tfm arr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; rm -rf arr9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/tfm/arr9t.tfm arr9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf ; rm -rf mhvb.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf/mhvb.vf mhvb.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf ; rm -rf mhvbi.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf/mhvbi.vf mhvbi.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf ; rm -rf mhvbiq.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf/mhvbiq.vf mhvbiq.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf ; rm -rf mhvbq.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf/mhvbq.vf mhvbq.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf ; rm -rf mhvr.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf/mhvr.vf mhvr.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf ; rm -rf mhvri.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf/mhvri.vf mhvri.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf ; rm -rf mhvriq.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf/mhvriq.vf mhvriq.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf ; rm -rf mhvrq.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/helvetic/vf/mhvrq.vf mhvrq.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf mntb.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/mntb.tfm mntb.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf mntbi.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/mntbi.tfm mntbi.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf mntbiq.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/mntbiq.tfm mntbiq.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf mntbq.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/mntbq.tfm mntbq.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf mntr.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/mntr.tfm mntr.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf mntri.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/mntri.tfm mntri.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf mntriq.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/mntriq.tfm mntriq.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf mntrq.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/mntrq.tfm mntrq.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tnb10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tnb10u.tfm tnb10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tnb2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tnb2n.tfm tnb2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tnb7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tnb7j.tfm tnb7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tnb8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tnb8u.tfm tnb8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tnb9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tnb9t.tfm tnb9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tni10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tni10u.tfm tni10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tni2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tni2n.tfm tni2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tni7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tni7j.tfm tni7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tni8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tni8u.tfm tni8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tni9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tni9t.tfm tni9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tnj10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tnj10u.tfm tnj10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tnj2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tnj2n.tfm tnj2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tnj7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tnj7j.tfm tnj7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tnj8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tnj8u.tfm tnj8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tnj9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tnj9t.tfm tnj9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tnr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tnr10u.tfm tnr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tnr2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tnr2n.tfm tnr2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tnr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tnr7j.tfm tnr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tnr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tnr8u.tfm tnr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; rm -rf tnr9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/tfm/tnr9t.tfm tnr9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf ; rm -rf mntb.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf/mntb.vf mntb.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf ; rm -rf mntbi.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf/mntbi.vf mntbi.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf ; rm -rf mntbiq.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf/mntbiq.vf mntbiq.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf ; rm -rf mntbq.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf/mntbq.vf mntbq.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf ; rm -rf mntr.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf/mntr.vf mntr.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf ; rm -rf mntri.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf/mntri.vf mntri.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf ; rm -rf mntriq.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf/mntriq.vf mntriq.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf ; rm -rf mntrq.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/timesnew/vf/mntrq.vf mntrq.vf )
( cd usr/lib/texmf/fonts/dvilj/monotype/symbol/tfm ; rm -rf msyr.tfm )
( cd usr/lib/texmf/fonts/dvilj/monotype/symbol/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/monotype/symbol/tfm/msyr.tfm msyr.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; rm -rf calm.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/albertus/tfm/calm.tfm calm.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; rm -rf calmq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/albertus/tfm/calmq.tfm calmq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; rm -rf calqx.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/albertus/tfm/calqx.tfm calqx.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; rm -rf calx.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/albertus/tfm/calx.tfm calx.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; rm -rf ale10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/albertus/tfm/ale10u.tfm ale10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; rm -rf ale6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/albertus/tfm/ale6j.tfm ale6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; rm -rf ale7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/albertus/tfm/ale7j.tfm ale7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; rm -rf ale8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/albertus/tfm/ale8u.tfm ale8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; rm -rf alr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/albertus/tfm/alr10u.tfm alr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; rm -rf alr6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/albertus/tfm/alr6j.tfm alr6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; rm -rf alr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/albertus/tfm/alr7j.tfm alr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; rm -rf alr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/albertus/tfm/alr8u.tfm alr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/vf ; rm -rf calm.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/albertus/vf/calm.vf calm.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/vf ; rm -rf calmq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/albertus/vf/calmq.vf calmq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/vf ; rm -rf calqx.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/albertus/vf/calqx.vf calqx.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/vf ; rm -rf calx.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/albertus/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/albertus/vf/calx.vf calx.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; rm -rf caob.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm/caob.tfm caob.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; rm -rf caobq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm/caobq.tfm caobq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; rm -rf caor.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm/caor.tfm caor.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; rm -rf caori.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm/caori.tfm caori.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; rm -rf caoriq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm/caoriq.tfm caoriq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; rm -rf caorq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm/caorq.tfm caorq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; rm -rf anb10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm/anb10u.tfm anb10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; rm -rf anb6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm/anb6j.tfm anb6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; rm -rf anb7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm/anb7j.tfm anb7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; rm -rf anb8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm/anb8u.tfm anb8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; rm -rf ani10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm/ani10u.tfm ani10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; rm -rf ani6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm/ani6j.tfm ani6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; rm -rf ani7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm/ani7j.tfm ani7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; rm -rf ani8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm/ani8u.tfm ani8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; rm -rf anr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm/anr10u.tfm anr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; rm -rf anr6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm/anr6j.tfm anr6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; rm -rf anr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm/anr7j.tfm anr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; rm -rf anr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/tfm/anr8u.tfm anr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/vf ; rm -rf caob.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/vf/caob.vf caob.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/vf ; rm -rf caobq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/vf/caobq.vf caobq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/vf ; rm -rf caor.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/vf/caor.vf caor.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/vf ; rm -rf caori.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/vf/caori.vf caori.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/vf ; rm -rf caoriq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/vf/caoriq.vf caoriq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/vf ; rm -rf caorq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/atqolive/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/atqolive/vf/caorq.vf caorq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/clarendo/tfm ; rm -rf ccdrqc.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/clarendo/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/clarendo/tfm/ccdrqc.tfm ccdrqc.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/clarendo/tfm ; rm -rf ccdrrc.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/clarendo/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/clarendo/tfm/ccdrrc.tfm ccdrrc.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/clarendo/tfm ; rm -rf clc10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/clarendo/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/clarendo/tfm/clc10u.tfm clc10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/clarendo/tfm ; rm -rf clc6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/clarendo/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/clarendo/tfm/clc6j.tfm clc6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/clarendo/tfm ; rm -rf clc7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/clarendo/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/clarendo/tfm/clc7j.tfm clc7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/clarendo/tfm ; rm -rf clc8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/clarendo/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/clarendo/tfm/clc8u.tfm clc8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/clarendo/vf ; rm -rf ccdrqc.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/clarendo/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/clarendo/vf/ccdrqc.vf ccdrqc.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/clarendo/vf ; rm -rf ccdrrc.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/clarendo/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/clarendo/vf/ccdrrc.vf ccdrrc.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf ccrb.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/ccrb.tfm ccrb.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf ccrbi.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/ccrbi.tfm ccrbi.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf ccrbiq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/ccrbiq.tfm ccrbiq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf ccrbq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/ccrbq.tfm ccrbq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf ccrr.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/ccrr.tfm ccrr.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf ccrri.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/ccrri.tfm ccrri.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf ccrriq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/ccrriq.tfm ccrriq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf ccrrq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/ccrrq.tfm ccrrq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf crb10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/crb10u.tfm crb10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf crb2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/crb2n.tfm crb2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf crb6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/crb6j.tfm crb6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf crb7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/crb7j.tfm crb7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf crb8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/crb8u.tfm crb8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf crb9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/crb9t.tfm crb9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf cri10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/cri10u.tfm cri10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf cri2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/cri2n.tfm cri2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf cri6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/cri6j.tfm cri6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf cri7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/cri7j.tfm cri7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf cri8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/cri8u.tfm cri8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf cri9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/cri9t.tfm cri9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf crj10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/crj10u.tfm crj10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf crj2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/crj2n.tfm crj2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf crj6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/crj6j.tfm crj6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf crj7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/crj7j.tfm crj7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf crj8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/crj8u.tfm crj8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf crj9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/crj9t.tfm crj9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf crr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/crr10u.tfm crr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf crr2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/crr2n.tfm crr2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf crr6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/crr6j.tfm crr6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf crr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/crr7j.tfm crr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf crr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/crr8u.tfm crr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; rm -rf crr9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/tfm/crr9t.tfm crr9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/vf ; rm -rf ccrb.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/vf/ccrb.vf ccrb.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/vf ; rm -rf ccrbi.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/vf/ccrbi.vf ccrbi.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/vf ; rm -rf ccrbiq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/vf/ccrbiq.vf ccrbiq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/vf ; rm -rf ccrbq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/vf/ccrbq.vf ccrbq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/vf ; rm -rf ccrr.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/vf/ccrr.vf ccrr.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/vf ; rm -rf ccrri.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/vf/ccrri.vf ccrri.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/vf ; rm -rf ccrriq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/vf/ccrriq.vf ccrriq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/vf ; rm -rf ccrrq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/courier/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/courier/vf/ccrrq.vf ccrrq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf cgmb.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/cgmb.tfm cgmb.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf cgmbi.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/cgmbi.tfm cgmbi.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf cgmbiq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/cgmbiq.tfm cgmbiq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf cgmbq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/cgmbq.tfm cgmbq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf cgmr.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/cgmr.tfm cgmr.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf cgmri.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/cgmri.tfm cgmri.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf cgmriq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/cgmriq.tfm cgmriq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf cgmrq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/cgmrq.tfm cgmrq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf gra10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/gra10u.tfm gra10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf gra6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/gra6j.tfm gra6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf gra7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/gra7j.tfm gra7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf gra8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/gra8u.tfm gra8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf grh10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/grh10u.tfm grh10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf grh6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/grh6j.tfm grh6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf grh7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/grh7j.tfm grh7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf grh8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/grh8u.tfm grh8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf grk10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/grk10u.tfm grk10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf grk6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/grk6j.tfm grk6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf grk7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/grk7j.tfm grk7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf grk8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/grk8u.tfm grk8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf grl10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/grl10u.tfm grl10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf grl6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/grl6j.tfm grl6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf grl7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/grl7j.tfm grl7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; rm -rf grl8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/tfm/grl8u.tfm grl8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/vf ; rm -rf cgmb.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/vf/cgmb.vf cgmb.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/vf ; rm -rf cgmbi.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/vf/cgmbi.vf cgmbi.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/vf ; rm -rf cgmbiq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/vf/cgmbiq.vf cgmbiq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/vf ; rm -rf cgmbq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/vf/cgmbq.vf cgmbq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/vf ; rm -rf cgmr.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/vf/cgmr.vf cgmr.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/vf ; rm -rf cgmri.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/vf/cgmri.vf cgmri.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/vf ; rm -rf cgmriq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/vf/cgmriq.vf cgmriq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/vf ; rm -rf cgmrq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/garamond/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/garamond/vf/cgmrq.vf cgmrq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf clgb.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/clgb.tfm clgb.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf clgbq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/clgbq.tfm clgbq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf clgr.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/clgr.tfm clgr.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf clgri.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/clgri.tfm clgri.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf clgriq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/clgriq.tfm clgriq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf clgrq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/clgrq.tfm clgrq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf lgb10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/lgb10u.tfm lgb10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf lgb2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/lgb2n.tfm lgb2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf lgb6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/lgb6j.tfm lgb6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf lgb7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/lgb7j.tfm lgb7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf lgb8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/lgb8u.tfm lgb8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf lgb9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/lgb9t.tfm lgb9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf lgi10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/lgi10u.tfm lgi10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf lgi2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/lgi2n.tfm lgi2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf lgi6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/lgi6j.tfm lgi6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf lgi7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/lgi7j.tfm lgi7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf lgi8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/lgi8u.tfm lgi8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf lgi9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/lgi9t.tfm lgi9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf lgr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/lgr10u.tfm lgr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf lgr2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/lgr2n.tfm lgr2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf lgr6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/lgr6j.tfm lgr6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf lgr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/lgr7j.tfm lgr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf lgr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/lgr8u.tfm lgr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; rm -rf lgr9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/tfm/lgr9t.tfm lgr9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/vf ; rm -rf clgb.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/vf/clgb.vf clgb.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/vf ; rm -rf clgbq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/vf/clgbq.vf clgbq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/vf ; rm -rf clgr.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/vf/clgr.vf clgr.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/vf ; rm -rf clgri.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/vf/clgri.vf clgri.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/vf ; rm -rf clgriq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/vf/clgriq.vf clgriq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/vf ; rm -rf clgrq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/lettrgth/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/lettrgth/vf/clgrq.vf clgrq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/marigold/tfm ; rm -rf cmgr.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/marigold/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/marigold/tfm/cmgr.tfm cmgr.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/marigold/tfm ; rm -rf cmgrq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/marigold/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/marigold/tfm/cmgrq.tfm cmgrq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/marigold/tfm ; rm -rf mrr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/marigold/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/marigold/tfm/mrr10u.tfm mrr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/marigold/tfm ; rm -rf mrr6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/marigold/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/marigold/tfm/mrr6j.tfm mrr6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/marigold/tfm ; rm -rf mrr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/marigold/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/marigold/tfm/mrr7j.tfm mrr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/marigold/tfm ; rm -rf mrr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/marigold/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/marigold/tfm/mrr8u.tfm mrr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/marigold/vf ; rm -rf cmgr.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/marigold/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/marigold/vf/cmgr.vf cmgr.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/marigold/vf ; rm -rf cmgrq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/marigold/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/marigold/vf/cmgrq.vf cmgrq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf copb.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/copb.tfm copb.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf copbi.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/copbi.tfm copbi.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf copbiq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/copbiq.tfm copbiq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf copbq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/copbq.tfm copbq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf copr.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/copr.tfm copr.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf copri.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/copri.tfm copri.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf copriq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/copriq.tfm copriq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf coprq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/coprq.tfm coprq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf omb10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/omb10u.tfm omb10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf omb6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/omb6j.tfm omb6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf omb7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/omb7j.tfm omb7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf omb8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/omb8u.tfm omb8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf omi10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/omi10u.tfm omi10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf omi6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/omi6j.tfm omi6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf omi7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/omi7j.tfm omi7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf omi8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/omi8u.tfm omi8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf omj10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/omj10u.tfm omj10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf omj6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/omj6j.tfm omj6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf omj7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/omj7j.tfm omj7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf omj8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/omj8u.tfm omj8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf omr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/omr10u.tfm omr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf omr6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/omr6j.tfm omr6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf omr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/omr7j.tfm omr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; rm -rf omr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/tfm/omr8u.tfm omr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/vf ; rm -rf copb.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/vf/copb.vf copb.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/vf ; rm -rf copbi.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/vf/copbi.vf copbi.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/vf ; rm -rf copbiq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/vf/copbiq.vf copbiq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/vf ; rm -rf copbq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/vf/copbq.vf copbq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/vf ; rm -rf copr.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/vf/copr.vf copr.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/vf ; rm -rf copri.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/vf/copri.vf copri.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/vf ; rm -rf copriq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/vf/copriq.vf copriq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/vf ; rm -rf coprq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/optima/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/optima/vf/coprq.vf coprq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/coronet/tfm ; rm -rf cotr.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/coronet/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/coronet/tfm/cotr.tfm cotr.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/coronet/tfm ; rm -rf cotrq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/coronet/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/coronet/tfm/cotrq.tfm cotrq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/coronet/tfm ; rm -rf cor10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/coronet/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/coronet/tfm/cor10u.tfm cor10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/coronet/tfm ; rm -rf cor6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/coronet/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/coronet/tfm/cor6j.tfm cor6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/coronet/tfm ; rm -rf cor7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/coronet/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/coronet/tfm/cor7j.tfm cor7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/coronet/tfm ; rm -rf cor8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/coronet/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/coronet/tfm/cor8u.tfm cor8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/coronet/vf ; rm -rf cotr.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/coronet/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/coronet/vf/cotr.vf cotr.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/coronet/vf ; rm -rf cotrq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/coronet/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/coronet/vf/cotrq.vf cotrq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf ctmb.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/ctmb.tfm ctmb.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf ctmbi.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/ctmbi.tfm ctmbi.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf ctmbiq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/ctmbiq.tfm ctmbiq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf ctmbq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/ctmbq.tfm ctmbq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf ctmr.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/ctmr.tfm ctmr.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf ctmri.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/ctmri.tfm ctmri.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf ctmriq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/ctmriq.tfm ctmriq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf ctmrq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/ctmrq.tfm ctmrq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf trb10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/trb10u.tfm trb10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf trb2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/trb2n.tfm trb2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf trb6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/trb6j.tfm trb6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf trb7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/trb7j.tfm trb7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf trb8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/trb8u.tfm trb8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf trb9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/trb9t.tfm trb9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf tri10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/tri10u.tfm tri10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf tri2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/tri2n.tfm tri2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf tri6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/tri6j.tfm tri6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf tri7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/tri7j.tfm tri7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf tri8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/tri8u.tfm tri8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf tri9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/tri9t.tfm tri9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf trj10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/trj10u.tfm trj10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf trj2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/trj2n.tfm trj2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf trj6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/trj6j.tfm trj6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf trj7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/trj7j.tfm trj7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf trj8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/trj8u.tfm trj8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf trj9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/trj9t.tfm trj9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf trr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/trr10u.tfm trr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf trr2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/trr2n.tfm trr2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf trr6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/trr6j.tfm trr6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf trr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/trr7j.tfm trr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf trr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/trr8u.tfm trr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; rm -rf trr9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/tfm/trr9t.tfm trr9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/times/vf ; rm -rf ctmb.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/times/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/vf/ctmb.vf ctmb.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/times/vf ; rm -rf ctmbi.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/times/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/vf/ctmbi.vf ctmbi.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/times/vf ; rm -rf ctmbiq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/times/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/vf/ctmbiq.vf ctmbiq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/times/vf ; rm -rf ctmbq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/times/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/vf/ctmbq.vf ctmbq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/times/vf ; rm -rf ctmr.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/times/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/vf/ctmr.vf ctmr.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/times/vf ; rm -rf ctmri.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/times/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/vf/ctmri.vf ctmri.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/times/vf ; rm -rf ctmriq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/times/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/vf/ctmriq.vf ctmriq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/times/vf ; rm -rf ctmrq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/times/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/times/vf/ctmrq.vf ctmrq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf cunb.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/cunb.tfm cunb.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf cunbi.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/cunbi.tfm cunbi.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf cunbic.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/cunbic.tfm cunbic.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf cunbiq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/cunbiq.tfm cunbiq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf cunbiqc.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/cunbiqc.tfm cunbiqc.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf cunbq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/cunbq.tfm cunbq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf cunbqc.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/cunbqc.tfm cunbqc.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf cunbrc.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/cunbrc.tfm cunbrc.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf cunm.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/cunm.tfm cunm.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf cunmi.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/cunmi.tfm cunmi.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf cunmic.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/cunmic.tfm cunmic.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf cunmiq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/cunmiq.tfm cunmiq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf cunmiqc.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/cunmiqc.tfm cunmiqc.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf cunmq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/cunmq.tfm cunmq.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf cunmqc.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/cunmqc.tfm cunmqc.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf cunmrc.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/cunmrc.tfm cunmrc.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf ucb10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/ucb10u.tfm ucb10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf ucb6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/ucb6j.tfm ucb6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf ucb7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/ucb7j.tfm ucb7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf ucb8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/ucb8u.tfm ucb8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf uci10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/uci10u.tfm uci10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf uci6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/uci6j.tfm uci6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf uci7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/uci7j.tfm uci7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf uci8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/uci8u.tfm uci8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf ucj10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/ucj10u.tfm ucj10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf ucj6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/ucj6j.tfm ucj6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf ucj7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/ucj7j.tfm ucj7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf ucj8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/ucj8u.tfm ucj8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf ucr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/ucr10u.tfm ucr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf ucr6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/ucr6j.tfm ucr6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf ucr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/ucr7j.tfm ucr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf ucr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/ucr8u.tfm ucr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf unb10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/unb10u.tfm unb10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf unb2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/unb2n.tfm unb2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf unb6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/unb6j.tfm unb6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf unb7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/unb7j.tfm unb7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf unb8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/unb8u.tfm unb8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf unb9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/unb9t.tfm unb9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf uni10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/uni10u.tfm uni10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf uni2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/uni2n.tfm uni2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf uni6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/uni6j.tfm uni6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf uni7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/uni7j.tfm uni7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf uni8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/uni8u.tfm uni8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf uni9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/uni9t.tfm uni9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf unj10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/unj10u.tfm unj10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf unj2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/unj2n.tfm unj2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf unj6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/unj6j.tfm unj6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf unj7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/unj7j.tfm unj7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf unj8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/unj8u.tfm unj8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf unj9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/unj9t.tfm unj9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf unr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/unr10u.tfm unr10u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf unr2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/unr2n.tfm unr2n.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf unr6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/unr6j.tfm unr6j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf unr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/unr7j.tfm unr7j.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf unr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/unr8u.tfm unr8u.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; rm -rf unr9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/tfm/unr9t.tfm unr9t.tfm )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; rm -rf cunb.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/vf/cunb.vf cunb.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; rm -rf cunbi.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/vf/cunbi.vf cunbi.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; rm -rf cunbic.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/vf/cunbic.vf cunbic.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; rm -rf cunbiq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/vf/cunbiq.vf cunbiq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; rm -rf cunbiqc.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/vf/cunbiqc.vf cunbiqc.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; rm -rf cunbq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/vf/cunbq.vf cunbq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; rm -rf cunbqc.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/vf/cunbqc.vf cunbqc.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; rm -rf cunbrc.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/vf/cunbrc.vf cunbrc.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; rm -rf cunm.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/vf/cunm.vf cunm.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; rm -rf cunmi.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/vf/cunmi.vf cunmi.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; rm -rf cunmic.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/vf/cunmic.vf cunmic.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; rm -rf cunmiq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/vf/cunmiq.vf cunmiq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; rm -rf cunmiqc.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/vf/cunmiqc.vf cunmiqc.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; rm -rf cunmq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/vf/cunmq.vf cunmq.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; rm -rf cunmqc.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/vf/cunmqc.vf cunmqc.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; rm -rf cunmrc.vf )
( cd usr/lib/texmf/fonts/dvilj/cg/univers/vf ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/cg/univers/vf/cunmrc.vf cunmrc.vf )
( cd usr/lib/texmf/fonts/dvilj/bh/wingding/tfm ; rm -rf hwir.tfm )
( cd usr/lib/texmf/fonts/dvilj/bh/wingding/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/dvilj/bh/wingding/tfm/hwir.tfm hwir.tfm )
( cd usr/man/preformat/cat1 ; rm -rf dvilj.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf /cdrom/live/usr/man/preformat/cat1/dvilj.1.gz dvilj.1.gz )
